BuildException class

A build error (val_latex has none; kept for type compatibility).

Inheritance

Constructors

BuildException(String message)
Creates a build error.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The message.
finalinherited
messageWithType → String
Type name used in messages.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited