FlutterMathException class abstract
Base of flutter_math_fork's exceptions.
- Implemented types
- Implementers
Constructors
- FlutterMathException(String message)
-
Creates an exception.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message.
final
- messageWithType → String
-
Type name used in messages.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited