MathOptions class
flutter_math_fork's rendering options.
- Annotations
Constructors
- MathOptions({MathStyle style = MathStyle.display, Color color = Colors.black, MathSize sizeUnderTextStyle = MathSize.normalsize, FontOptions? textFontOptions, FontOptions? mathFontOptions, double? fontSize, double? logicalPpi})
-
Creates options.
const
Properties
- color → Color
-
Colour.
final
- fontSize → double
-
Base font size in logical pixels.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logicalPpi → double?
-
Ignored.
final
- mathFontOptions → FontOptions?
-
Math font request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeUnderTextStyle → MathSize
-
Size relative to fontSize.
final
- style → MathStyle
-
Style.
final
- textFontOptions → FontOptions?
-
Text font request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited