MathSize enum

flutter_math_fork's size names, relative to the text style's size.

Inheritance
Available extensions

Values

tiny → const MathSize

0.5×.

const MathSize(0.5)
size2 → const MathSize

0.6×.

const MathSize(0.6)
scriptsize → const MathSize

0.7×.

const MathSize(0.7)
footnotesize → const MathSize

0.8×.

const MathSize(0.8)
small → const MathSize

0.9×.

const MathSize(0.9)
normalsize → const MathSize

1×.

const MathSize(1)
large → const MathSize

1.2×.

const MathSize(1.2)
Large → const MathSize

1.44×.

const MathSize(1.44)
LARGE → const MathSize

1.728×.

const MathSize(1.728)
huge → const MathSize

2.074×.

const MathSize(2.074)
HUGE → const MathSize

2.488×.

const MathSize(2.488)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeMultiplier → double
Multiplier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MathSize>
A constant List of the values in this enum, in order of their declaration.