FontOptions class
Font request (only the weight is honoured: bold math via \boldsymbol).
- Annotations
Constructors
-
FontOptions({String fontFamily = 'Main', FontWeight fontWeight = FontWeight.normal, FontStyle fontShape = FontStyle.normal, List<
FontOptions> fallback = const []}) -
Creates font options.
const
Properties
-
fallback
→ List<
FontOptions> -
Fallbacks (ignored).
final
- fontFamily → String
-
KaTeX font family name (ignored: val_latex uses its own fonts).
final
- fontShape → FontStyle
-
Shape (ignored).
final
- fontWeight → FontWeight
-
Weight; bold makes the formula bold.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited