Math class
flutter_math_fork's Math widget, backed by val_latex.
- Inheritance
- Implementers
Constructors
- Math.tex(String expression, {Key? key, MathStyle mathStyle = MathStyle.display, TextStyle? textStyle, OnErrorFallback onErrorFallback = defaultOnErrorFallback, TexParserSettings settings = const TexParserSettings(), double? textScaleFactor, MathOptions? options})
-
Renders
expression.const
Properties
- expression → String
-
TeX source.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mathStyle → MathStyle
-
Style (display style is set inline, not as a full-width block).
final
- onErrorFallback → OnErrorFallback
-
Shown instead of the formula when it has errors.
final
- options → MathOptions?
-
Explicit options; override mathStyle and textStyle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → TexParserSettings
-
Parser settings.
final
- textScaleFactor → double?
-
Overrides the platform text scale.
final
- textStyle → TextStyle?
-
Size and colour.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultOnErrorFallback(
FlutterMathException error) → Widget - flutter_math_fork's default fallback: the error message.