MathStyle enum
flutter_math_fork's styles. Cramped variants render like their uncramped style.
Values
- display → const MathStyle
-
Display style.
- displayCramped → const MathStyle
-
Display style, cramped.
- text → const MathStyle
-
Text style.
- textCramped → const MathStyle
-
Text style, cramped.
- script → const MathStyle
-
Script style.
- scriptCramped → const MathStyle
-
Script style, cramped.
- scriptscript → const MathStyle
-
Scriptscript style.
- scriptscriptCramped → const MathStyle
-
Scriptscript style, cramped.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited