TexParserSettings class
flutter_math_fork's parser settings.
- Annotations
Constructors
-
TexParserSettings({bool displayMode = false, bool throwOnError = true, Map<
String, String> macros = const {}, int maxExpand = 1000, Strict strict = Strict.warn, Strict strictFun(String code, String message, Object? token)?, bool globalGroup = false, bool colorIsTextColor = false}) -
Creates settings.
const
Properties
- colorIsTextColor → bool
-
\colortakes an argument.final - displayMode → bool
-
Display mode.
final
- globalGroup → bool
-
Definitions persist across formulas.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
macros
→ Map<
String, String> -
Macro name → body.
final
- maxExpand → int
-
Expansion limit.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strict → Strict
-
Strictness.
final
- strictFun → Strict Function(String code, String message, Object? token)?
-
Per-case strictness.
final
- throwOnError → bool
-
Ignored: val_latex never throws; errors reach
onErrorFallback.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited