Affine class final
An affine map (x, y) → (a·x + c·y + e, b·x + d·y + f).
Constructors
Properties
- a → double
-
Coefficients.
final
- b → double
-
Coefficients.
final
- c → double
-
Coefficients.
final
- d → double
-
Coefficients.
final
- e → double
-
Coefficients.
final
- f → double
-
Coefficients.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
double x, double y) → (double, double) -
The image of (
x,y). -
moved(
double dx, double dy) → Affine -
This map, then a move by (
dx,dy). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
List< PathCommand> commands) → List<PathCommand> - The path commands mapped.
-
times(
Affine inner) → Affine -
This map after
inner:this(inner(p)). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override