DiagramLabel class final
A label on a DiagramArrow: "f", "f"', "f" near start.
Constructors
-
DiagramLabel(MathNode body, {List<
String> options = const [], bool swap = false, double position = 0.5, DiagramLabelPlacement placement = DiagramLabelPlacement.auto, LatexColor? color}) -
Creates a label.
const
Properties
- body → MathNode
-
The label, laid out as math (in script style).
final
- color → LatexColor?
-
Its colour, or null for the arrow's.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ List<
String> -
The options after the closing quote, as written (
'for a swap), for writing the label back.final - placement → DiagramLabelPlacement
-
How it is placed.
final
- position → double
-
Where along the arrow, from 0 (start) to 1 (end):
near startis 0.25,near end0.75.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swap → bool
-
On the arrow's right instead of its left (
',swap).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited