SpeechLanguage enum
A language for spoken math.
Values
- english → const SpeechLanguage
-
English (ClearSpeak-like phrasing).
- arabic → const SpeechLanguage
-
Arabic (Modern Standard Arabic school phrasing).
- spanish → const SpeechLanguage
-
Spanish. DRAFT: not yet checked by a native reader.
- french → const SpeechLanguage
-
French. DRAFT: not yet checked by a native reader.
- german → const SpeechLanguage
-
German. DRAFT: not yet checked by a native reader.
- portuguese → const SpeechLanguage
-
Portuguese. DRAFT: not yet checked by a native reader.
- bengali → const SpeechLanguage
-
Bengali, words after what they govern (postpositions). DRAFT: not yet checked by a native reader.
- hindi → const SpeechLanguage
-
Hindi, words after what they govern (postpositions). DRAFT: not yet checked by a native reader.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SpeechLanguage> - A constant List of the values in this enum, in order of their declaration.